@@ -5,13 +5,13 @@ from polymorphic.models import PolymorphicTypeInvalid
 from rest_framework import viewsets, renderers
 from rest_framework.response import Response
 
-from OpenHubAPI.data.forms.forms import HardwareForm, HardwareDHT22Form, HardwareMCP3008Form, HardwareModProbeForm, \
+from data.forms.forms import HardwareForm, HardwareDHT22Form, HardwareMCP3008Form, HardwareModProbeForm, \
     HardwarePiPicoForm, HardwareVEML7700Form, HardwareTypeForm, ChannelForm, HardwareConfigForm, AccessoryForm, \
     CalibrationForm, CalibrationConstantForm, HubForm, HardwareIOTypeForm, SPIIoForm, PwmIoForm, SerialIoForm, \
     I2cIoForm, DeviceFileIoForm, MCPAnalogIoForm, PiPicoAnalogIoForm, PiGpioForm, HardwareIoForm
-from OpenHubAPI.data.models.models import Hardware, DHT22, MCP3008, ModProbe, PiPico, VEML7700, Accessory, Calibration, \
+from data.models.models import Hardware, DHT22, MCP3008, ModProbe, PiPico, VEML7700, Accessory, Calibration, \
     CalibrationConstants, Channel, Hub, HardwareIO
-from OpenHubAPI.data.serializers.serializers import HardwareSerializer, ChannelSerializer, AccessorySerializer, \
+from data.serializers.serializers import HardwareSerializer, ChannelSerializer, AccessorySerializer, \
     CalibrationSerializer, HubSerializer, HardwareIOSerializer
 
 SPI = 'SPI'
